@@ -51,6 +51,7 @@ pub struct ArcConfig
     pub current_len: AtomicUsize,
     pub sample_rate: AtomicUsize,
     pub channels: AtomicUsize,
+    pub monotonic_song_index: AtomicUsize,
     pub home_dir: PathBuf,
     pub config_dir: PathBuf,
     pub conffile: Conffile,
@@ -76,6 +77,7 @@ impl ArcConfig
             current_len: AtomicUsize::new(0),
             sample_rate: AtomicUsize::new(1),
             channels: AtomicUsize::new(1),
+            monotonic_song_index: AtomicUsize::new(0),
             home_dir,
             config_dir: conffile_dir,
             conffile,
