@@ -11,26 +11,26 @@ memory-tight = Memory is very tight, stopping …
 new-song-found = Found a new song: { $filename }
 no-songs = No playable songs
 print-playing-song = Printing information about the playing song
-title = Title
-album = Album
-artist = Artist
-album-artist = Album artist
-year = Year
-genre = Genre
-date-recorded = Date recorded
-date-released = Date released
-disc = Disc #
-discs-total = Disc total #
-track = Track #
-tracks-total = Tracks total #
-duration = Duration
-lyrics = Lyrics
-sync-lyrics = Synchronized lyrics
-comment = Comment
-num-pictures = Pictures #
+title = Title: { $text }
+album = Album: { $text }
+artist = Artist: { $text }
+album-artist = Album artist: { $text }
+year = Year: { $text }
+genre = Genre: { $text }
+date-recorded = Date recorded: { $text }
+date-released = Date released: { $text }
+disc = Disc #: { $text }
+discs-total = Disc total #: { $text }
+track = Track #: { $text }
+tracks-total = Tracks total #: { $text }
+duration = Duration: { $text }
+lyrics = Lyrics: { $text }
+sync-lyrics = Synchronized lyrics: { $text }
+comment = Comment: { $text }
+num-pictures = Pictures #: { $text }
 ext-links = ————Extended Links————
 ext-texts = ————Extended Texts————
-metadata-unsupported = Metadata is not supported for this song
+metadata-unsupported = Metadata is not supported for this song: { $err }
 print-info-unreachable = this shouldn't be reached
 max-likelihood-reached = Maximal playing likelihood already reached
 likelihood-increased = playing likelihood increased to { $likelihood }
@@ -96,5 +96,7 @@ unknown-artist = Unknown artist
 previous = Will play previous song.
 controller-out = Controller channel out of scope; this is a bug, please report it
 too-many-tries = Too many unsuccessful tries to read a song were made; probably all songs are unplayable; ending …
+positive-bonus = Increased likelihood of this repeating song to { $bonus }
+negative-bonus = Decreased likelihood of this repeating song to { $bonus }
 ";
 pub static ENGLISH_L10N_LANG_ID: &str = "en-US";
