@@ -12,26 +12,26 @@ memory-tight = RAM ist sehr knapp, stoppe …
 new-song-found = Neues Lied gefunden: { $filename }
 no-songs = Keine spielbaren Lieder
 print-playing-song = Zeige Informationen über das aktuelle Lied an
-title = Titel
-album = Album
-artist = Künstler
-album-artist = Künstler des Albums
-year = Jahr
-genre = Genre
-date-recorded = Aufzeichnungsjahr
-date-released = Veröffentlichungsjahr
-disc = CDs #
-discs-total = CDs insgesamt #
-track = Tracks #
-tracks-total = Tracks insgesamt #
-duration = Dauer
-lyrics = Liedtext
-sync-lyrics = Synchronisierter Liedtext
-comment = Kommentar
-num-pictures = Bilder #
+title = Titel: { $text }
+album = Album: { $text }
+artist = Künstler: { $text }
+album-artist = Künstler des Albums: { $text }
+year = Jahr: { $text }
+genre = Genre: { $text }
+date-recorded = Aufzeichnungsjahr: { $text }
+date-released = Veröffentlichungsjahr: { $text }
+disc = CDs #: { $text }
+discs-total = CDs insgesamt #: { $text }
+track = Tracks #: { $text }
+tracks-total = Tracks insgesamt #: { $text }
+duration = Dauer: { $text }
+lyrics = Liedtext: { $text }
+sync-lyrics = Synchronisierter Liedtext: { $text }
+comment = Kommentar: { $text }
+num-pictures = Bilder #: { $text }
 ext-links = ————Extended Links————
 ext-texts = ————Extended Texts————
-metadata-unsupported = Metadaten sind nicht unterstützt in diesem Lied
+metadata-unsupported = Metadaten sind nicht unterstützt in diesem Lied: { $err }
 print-info-unreachable = Das sollte nicht erreicht werden
 max-likelihood-reached = Maximale {-likelihood} ist schon erreicht
 likelihood-increased = {-likelihood} erhöht auf { $likelihood }
@@ -82,8 +82,8 @@ repeat-once = Diese Lied einmal wiederholen
 repeat-forever = Diese Lied ewig wiederholen
 skip-to-previous = Zum vorherigen Lied springen
 help-header = Drücke die Taste, die zu dem Befehl gehört, der ausgeführt werden soll:
-command-reading-problem = Problem mit dm Lesen von Befehlen; stoppe …
-reading-song-problem = Problem das Lied { $path } zu lesen : { $err }
+command-reading-problem = Problem mit dem Lesen von Befehlen; stoppe …
+reading-song-problem = Problem das Lied { $path } zu lesen: { $err }
 choosing-new-song = Wähle neues Lied
 playing-song = Gespieltes Lied: { $song }
 playing-song-unknown = Spiele Lied mit einem komischen Namen
@@ -97,5 +97,7 @@ unknown-artist = Unbekannter Künstler
 previous = Werde das vorherige Lied spielen
 controller-out = Controllerkanal ist out of scope; das ist ein Bug, bitte melde ihn
 too-many-tries = Zu viele erfolglose Versuche ein Lied zu lesen; wahrscheinlich sind alle Lieder unspielbar; stoppe …
+positive-bonus = {-likelihood} wegen Wiederholung auf { $bonus } erhöht
+negative-bonus = {-likelihood} wegen Wiederholung auf { $bonus } vermindert
 ";
 pub static GERMAN_L10N_LANG_ID: &str = "de-DE";
