@@ -1,6 +1,5 @@
-use std::{fs::File, io::Write, sync::Arc};
+use std::{cmp::Ordering, fs::File, io::Write, sync::Arc};
 
-use log::{debug, error, info};
 use rand::random;
 use walkdir::WalkDir;
 
@@ -8,7 +7,7 @@ use crate::{
     config::{ArcConfig, Config},
     csv::Csv,
     err::Error,
-    l10n::L10n,
+    l10n::{messages::Message, L10n},
     matcher::BigAction,
 };
 
@@ -51,7 +50,7 @@ impl L10nHelper
     {
         Self {
             l10n,
-            err_msg: l10n.get("saving-state-err", vec![]),
+            err_msg: l10n.get(Message::SavingStateErr),
         }
     }
 }
@@ -66,7 +65,7 @@ impl Drop for Songs
         {
             Ok(()) =>
             {
-                println!("{}", self.l10n_helper.l10n.get("state-saved", vec![]));
+                self.l10n_helper.l10n.write(Message::StateSaved);
             }
             Err(e) =>
             {
@@ -118,10 +117,7 @@ impl Songs
 
             if !songs.songs.iter().any(|x| x.name == filename)
             {
-                info!(
-                    "{}",
-                    l10n.get("new-song-found", vec![("filename", filename.clone())])
-                );
+                l10n.write(Message::NewSongFound(filename.clone()));
 
                 songs.songs.push(Song {
                     name: filename,
@@ -140,51 +136,68 @@ impl Songs
     {
         let total = self.total_likelihood();
 
-        debug!(
-            "{}",
-            l10n.get_num("total-playing-likelihood", vec![("val", total)])
-        );
+        l10n.write(Message::TotalPlayingLikelihood(total));
 
         if total == 0
         {
-            error!("{}", l10n.get("no-songs", vec![]));
+            l10n.write(Message::NoSongs);
             return BigAction::Quit;
         }
 
-        if config.song_index != 0
+        if config.songlist.len() == config.song_index
         {
-            let song = &mut self.songs[config.songlist[config.song_index - 1]];
+            let mut song_number = (random::<u64>() % total as u64) as _;
 
-            if config.repeat == Repeat::Once
+            for (pos, song) in self.songs.iter_mut().enumerate()
+            {
+                if song.num >= song_number
+                {
+                    config.songlist.push(pos);
+                    break;
+                }
+                song_number -= song.num;
+            }
+        }
+
+        let index = config.songlist[config.song_index];
+
+        if config.repeat != Repeat::Not
+        {
+            self.songs[index].num = (self.songs[index].num as i64
+                + config.arc_config.conffile.repeat_bonus)
+                .clamp(0, u32::MAX as _)
+                .try_into()
+                .unwrap();
+
+            match config.arc_config.conffile.repeat_bonus.cmp(&0)
+            {
+                Ordering::Greater => l10n.write(Message::PositiveBonus(self.songs[index].num)),
+                Ordering::Less =>
+                {
+                    l10n.write(Message::NegativeBonus(self.songs[index].num));
+                    if self.songs[index].num == 0
+                    {
+                        l10n.write(Message::SongNever);
+                    }
+                }
+                Ordering::Equal =>
+                {}
+            }
+        }
+
+        match config.repeat
+        {
+            Repeat::Not => config.song_index += 1,
+            Repeat::Once =>
             {
                 config.repeat = Repeat::Not;
-                return f(song, config);
-            };
-            if config.repeat == Repeat::Always
-            {
-                return f(song, config);
-            }
-            if config.song_index != config.songlist.len()
-            {
                 config.song_index += 1;
-                return f(song, config);
             }
+            Repeat::Always =>
+            {}
         }
 
-        let mut song_number = (random::<u64>() % total as u64) as _;
-
-        for (pos, song) in self.songs.iter_mut().enumerate()
-        {
-            if song.num >= song_number
-            {
-                config.songlist.push(pos);
-                config.song_index += 1;
-                return f(song, config);
-            }
-            song_number -= song.num;
-        }
-
-        unreachable!();
+        f(&mut self.songs[index], config)
     }
 }
 
